=== modified file 'drizzled/plugin/info_schema_table.h'
--- drizzled/plugin/info_schema_table.h	2010-01-06 02:20:42 +0000
+++ drizzled/plugin/info_schema_table.h	2010-01-15 01:41:40 +0000
@@ -323,7 +323,30 @@
       requested_object(req_object),
       column_info(in_column_info),
       rows(),
-      i_s_methods(in_methods)
+      i_s_methods(in_methods),
+      plugin_name("")
+  {}
+
+  InfoSchemaTable(const std::string& tab_name,
+                  Columns& in_column_info,
+                  int idx_col1,
+                  int idx_col2,
+                  bool in_hidden,
+                  bool in_opt_possible,
+                  uint32_t req_object,
+                  InfoSchemaMethods *in_methods,
+                  const std::string in_plugin_name)
+    :
+      Plugin(tab_name, "InfoSchemaTable"),
+      hidden(in_hidden),
+      is_opt_possible(in_opt_possible),
+      first_column_index(idx_col1),
+      second_column_index(idx_col2),
+      requested_object(req_object),
+      column_info(in_column_info),
+      rows(),
+      i_s_methods(in_methods),
+      plugin_name(in_plugin_name)
   {}
 
   explicit InfoSchemaTable(const std::string& tab_name)
@@ -336,7 +359,8 @@
       requested_object(0),
       column_info(),
       rows(),
-      i_s_methods(NULL)
+      i_s_methods(NULL),
+      plugin_name("")
   {}
 
   virtual ~InfoSchemaTable()
@@ -486,6 +510,14 @@
   }
 
   /**
+   * @return the plugin name.
+   */
+  const std::string &getPluginName() const
+  {
+    return plugin_name;
+  }
+
+  /**
    * @return the columns for this I_S table
    */
   const Columns &getColumns() const
@@ -589,6 +621,12 @@
    */
   InfoSchemaMethods *i_s_methods;
 
+  /**
+   * The name of the plugin associated with this I_S table
+   * NULL for non I_S tables. 
+   */ 
+  const std::string plugin_name; 
+
 public:
   static bool addPlugin(plugin::InfoSchemaTable *schema_table);
   static void removePlugin(plugin::InfoSchemaTable *table);

=== modified file 'plugin/info_schema/tables.cc'
--- plugin/info_schema/tables.cc	2010-01-09 01:34:52 +0000
+++ plugin/info_schema/tables.cc	2010-01-12 19:58:01 +0000
@@ -215,6 +215,13 @@
                                             0,
                                             "Comment"));
 
+  columns->push_back(new plugin::ColumnInfo("PLUGIN_NAME",
+                                            64,
+                                            DRIZZLE_TYPE_VARCHAR,
+                                            0,
+                                            MY_I_S_MAYBE_NULL,
+                                            "Plugin_name"));
+
   return columns;
 }
 
@@ -287,8 +294,10 @@
   table->setWriteSet(18);
   table->setWriteSet(19);
   table->setWriteSet(20);
+  table->setWriteSet(21);
   table->field[1]->store(db_name->str, db_name->length, cs);
   table->field[2]->store(table_name->str, table_name->length, cs);
+
   if (res)
   {
     /*
@@ -365,6 +374,20 @@
       table->field[20]->store(share->getComment(),
                               share->getCommentLength(), cs);
 
+    drizzled::plugin::InfoSchemaTable *tmp_table= 
+      drizzled::plugin::InfoSchemaTable::getTable(table_name->str);
+
+    if (tmp_table != NULL)
+    {
+      const std::string &plugin_name= tmp_table->getPluginName();
+
+      if (! plugin_name.empty())
+      {
+        table->field[21]->set_notnull();
+        table->field[21]->store(plugin_name.c_str(), plugin_name.size(), cs);
+      }
+    }
+ 
     if (cursor)
     {
       cursor->info(HA_STATUS_VARIABLE | 

=== modified file 'plugin/memcached_stats/memcached_stats.cc'
--- plugin/memcached_stats/memcached_stats.cc	2009-12-21 09:40:31 +0000
+++ plugin/memcached_stats/memcached_stats.cc	2010-01-03 23:56:16 +0000
@@ -137,7 +137,8 @@
   memcached_stats_table= new(std::nothrow) plugin::InfoSchemaTable("MEMCACHED_STATS",
                                                            memcached_stats_columns,
                                                            -1, -1, false, false, 0,
-                                                           memcached_stats_methods);
+                                                           memcached_stats_methods,
+                                                           "MEMCACHED_STATS");
   if (! memcached_stats_table)
   {
     return true;
@@ -147,7 +148,8 @@
     new(std::nothrow) plugin::InfoSchemaTable("MEMCACHED_ANALYSIS",
                                       memcached_analysis_columns,
                                       -1, -1, false, false, 0,
-                                      memcached_analysis_methods);
+                                      memcached_analysis_methods,
+                                      "MEMCACHED_STATS");
   if (! memcached_analysis_table)
   {
     return true;

=== modified file 'tests/r/alter_table.result'
--- tests/r/alter_table.result	2009-12-01 17:50:17 +0000
+++ tests/r/alter_table.result	2010-01-03 23:56:16 +0000
@@ -350,15 +350,15 @@
 create TEMPORARY table t1 (a int, b int, c int, d int, e int, f int, g int, h int,i int, primary key (a,b,c,d,e,f,g,i,h)) engine=MyISAM;
 insert into t1 (a,b,c,d,e,f,g,h,i) values(1,1,1,1,1,1,1,1,1);
 show table status like 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 alter table t1 modify a int;
 show table status like 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 drop table t1;
 create TEMPORARY table t1 (a int not null default 0, b int not null default 0, c int not null default 0, d int not null default 0, e int not null default 0, f int not null default 0, g int not null default 0, h int not null default 0,i int not null default 0, primary key (a,b,c,d,e,f,g,i,h)) engine=MyISAM;
 insert into t1 (a) values(1);
 show table status like 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 drop table t1;
 CREATE TABLE t1 (a int PRIMARY KEY, b INT UNIQUE);
 ALTER TABLE t1 DROP PRIMARY KEY;

=== modified file 'tests/r/broken_table_proto_file.result'
--- tests/r/broken_table_proto_file.result	2010-01-09 01:22:42 +0000
+++ tests/r/broken_table_proto_file.result	2010-01-12 19:58:01 +0000
@@ -1,7 +1,7 @@
 flush tables;
 SHOW TABLE STATUS like 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
-t1	NULL	NULL	NULL	NULL	#	#	#	#	NULL	NULL	NULL	NULL	NULL	NULL	NULL	NULL	Incorrect information in file: './test/t1'
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
+t1	NULL	NULL	NULL	NULL	#	#	#	#	NULL	NULL	NULL	NULL	NULL	NULL	NULL	NULL	Incorrect information in file: './test/t1'	NULL
 show create table t1;
 ERROR HY000: Incorrect information in file: './test/t1'
 drop table if exists t1;

=== modified file 'tests/r/heap.result'
--- tests/r/heap.result	2009-12-01 17:50:17 +0000
+++ tests/r/heap.result	2010-01-03 23:56:16 +0000
@@ -693,7 +693,7 @@
 create temporary table t1 (c char(10)) engine=memory;
 create temporary table t2 (c varchar(10)) engine=memory;
 show table status like 't_';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 drop table t1, t2;
 CREATE TEMPORARY TABLE t1(a VARCHAR(1), b VARCHAR(2), c VARCHAR(256),
 KEY(a), KEY(b), KEY(c)) ENGINE=MEMORY;

=== modified file 'tests/r/information_schema.result'
--- tests/r/information_schema.result	2009-12-20 20:59:46 +0000
+++ tests/r/information_schema.result	2010-01-05 01:41:25 +0000
@@ -122,7 +122,7 @@
 SELECT table_schema, count(*) FROM information_schema.TABLES
 WHERE table_name NOT LIKE 'ndb_%' AND 
 table_name NOT LIKE 'falcon%' AND
-table_name NOT LIKE 'MEMCACHED%'
+plugin_name IS NULL
 GROUP BY TABLE_SCHEMA;
 table_schema	count(*)
 information_schema	24
@@ -247,7 +247,7 @@
 c2.column_name LIKE '%SCHEMA%'
         )
 AND t.table_name NOT LIKE 'falcon%'
-  AND t.table_name NOT LIKE 'MEMCACHED%';
+  AND t.plugin_name IS NULL;
 table_name	column_name
 CHARACTER_SETS	CHARACTER_SET_NAME
 COLLATIONS	COLLATION_NAME
@@ -288,7 +288,7 @@
 c2.column_name LIKE '%SCHEMA%'
         )
 AND t.table_name NOT LIKE 'falcon%'
-  AND t.table_name NOT LIKE 'MEMCACHED%';
+  AND t.plugin_name IS NULL;
 table_name	column_name
 CHARACTER_SETS	CHARACTER_SET_NAME
 COLLATIONS	COLLATION_NAME
@@ -344,7 +344,7 @@
 on t.table_schema = c1.table_schema AND t.table_name = c1.table_name
 where t.table_schema = 'information_schema' AND
 t.table_name not like 'falcon%' AND
-t.table_name not like 'MEMCACHED%' AND
+t.plugin_name IS NULL AND
 c1.ordinal_position =
 (select isnull(c2.column_type) -
 isnull(group_concat(c2.table_schema, '.', c2.table_name)) +
@@ -447,11 +447,11 @@
 select * from `information_schema`.`STATISTICS` where `TABLE_NAME` = NULL;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	NON_UNIQUE	INDEX_SCHEMA	INDEX_NAME	SEQ_IN_INDEX	COLUMN_NAME	COLLATION	CARDINALITY	SUB_PART	PACKED	NULLABLE	INDEX_TYPE	COMMENT	INDEX_COMMENT
 select * from information_schema.tables where table_schema = NULL;
-TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE	ENGINE	VERSION	ROW_FORMAT	TABLE_ROWS	AVG_ROW_LENGTH	DATA_LENGTH	MAX_DATA_LENGTH	INDEX_LENGTH	DATA_FREE	AUTO_INCREMENT	CREATE_TIME	UPDATE_TIME	CHECK_TIME	TABLE_COLLATION	CHECKSUM	CREATE_OPTIONS	TABLE_COMMENT
+TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE	ENGINE	VERSION	ROW_FORMAT	TABLE_ROWS	AVG_ROW_LENGTH	DATA_LENGTH	MAX_DATA_LENGTH	INDEX_LENGTH	DATA_FREE	AUTO_INCREMENT	CREATE_TIME	UPDATE_TIME	CHECK_TIME	TABLE_COLLATION	CHECKSUM	CREATE_OPTIONS	TABLE_COMMENT	PLUGIN_NAME
 select * from information_schema.tables where table_catalog = NULL;
-TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE	ENGINE	VERSION	ROW_FORMAT	TABLE_ROWS	AVG_ROW_LENGTH	DATA_LENGTH	MAX_DATA_LENGTH	INDEX_LENGTH	DATA_FREE	AUTO_INCREMENT	CREATE_TIME	UPDATE_TIME	CHECK_TIME	TABLE_COLLATION	CHECKSUM	CREATE_OPTIONS	TABLE_COMMENT
+TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE	ENGINE	VERSION	ROW_FORMAT	TABLE_ROWS	AVG_ROW_LENGTH	DATA_LENGTH	MAX_DATA_LENGTH	INDEX_LENGTH	DATA_FREE	AUTO_INCREMENT	CREATE_TIME	UPDATE_TIME	CHECK_TIME	TABLE_COLLATION	CHECKSUM	CREATE_OPTIONS	TABLE_COMMENT	PLUGIN_NAME
 select * from information_schema.tables where table_name = NULL;
-TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE	ENGINE	VERSION	ROW_FORMAT	TABLE_ROWS	AVG_ROW_LENGTH	DATA_LENGTH	MAX_DATA_LENGTH	INDEX_LENGTH	DATA_FREE	AUTO_INCREMENT	CREATE_TIME	UPDATE_TIME	CHECK_TIME	TABLE_COLLATION	CHECKSUM	CREATE_OPTIONS	TABLE_COMMENT
+TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE	ENGINE	VERSION	ROW_FORMAT	TABLE_ROWS	AVG_ROW_LENGTH	DATA_LENGTH	MAX_DATA_LENGTH	INDEX_LENGTH	DATA_FREE	AUTO_INCREMENT	CREATE_TIME	UPDATE_TIME	CHECK_TIME	TABLE_COLLATION	CHECKSUM	CREATE_OPTIONS	TABLE_COMMENT	PLUGIN_NAME
 select * from `information_schema`.`TABLE_CONSTRAINTS` where `TABLE_SCHEMA` = NULL;
 CONSTRAINT_CATALOG	CONSTRAINT_SCHEMA	CONSTRAINT_NAME	TABLE_SCHEMA	TABLE_NAME	CONSTRAINT_TYPE
 select * from `information_schema`.`TABLE_CONSTRAINTS` where `TABLE_NAME` = NULL;
@@ -536,7 +536,9 @@
 utf8_unicode_ci	utf8
 SELECT table_name, column_name
 FROM information_schema.columns
-WHERE table_name NOT LIKE 'MEMCACHED%'
+WHERE table_name IN
+(SELECT table_name FROM information_schema.tables 
+WHERE plugin_name IS NULL)
 ORDER BY table_name;
 table_name	column_name
 CHARACTER_SETS	CHARACTER_SET_NAME
@@ -697,9 +699,9 @@
 TABLES	CHECKSUM
 TABLES	CREATE_OPTIONS
 TABLES	TABLE_COMMENT
+TABLES	PLUGIN_NAME
 TABLES	INDEX_LENGTH
 TABLES	MAX_DATA_LENGTH
-TABLES	DATA_LENGTH
 TABLES	TABLE_CATALOG
 TABLES	TABLE_SCHEMA
 TABLES	TABLE_NAME
@@ -709,6 +711,7 @@
 TABLES	ROW_FORMAT
 TABLES	TABLE_ROWS
 TABLES	AVG_ROW_LENGTH
+TABLES	DATA_LENGTH
 TABLE_CONSTRAINTS	TABLE_NAME
 TABLE_CONSTRAINTS	TABLE_SCHEMA
 TABLE_CONSTRAINTS	CONSTRAINT_NAME
@@ -1052,7 +1055,7 @@
 CONSTRAINT_CATALOG	CONSTRAINT_SCHEMA	CONSTRAINT_NAME	TABLE_SCHEMA	TABLE_NAME	CONSTRAINT_TYPE
 SELECT table_schema, table_name
 FROM information_schema.tables
-WHERE table_name NOT LIKE 'MEMCACHED%'
+WHERE plugin_name IS NULL
 ORDER BY table_name;
 table_schema	table_name
 information_schema	CHARACTER_SETS

=== modified file 'tests/r/myisam.result'
--- tests/r/myisam.result	2009-11-26 02:37:40 +0000
+++ tests/r/myisam.result	2010-01-03 23:56:16 +0000
@@ -632,7 +632,7 @@
 9
 DELETE FROM t1 WHERE _id < 8;
 SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 CHECK TABLE t1;
 Table	Op	Msg_type	Msg_text
 test.t1	check	status	OK
@@ -641,7 +641,7 @@
 Table	Op	Msg_type	Msg_text
 test.t1	check	status	OK
 SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 SELECT _id FROM t1;
 _id
 8
@@ -653,7 +653,7 @@
 myisam_repair_threads	1
 CREATE TEMPORARY TABLE t1 (c1 TEXT) ENGINE=MyISAM;
 SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 DROP TABLE t1;
 CREATE TEMPORARY TABLE t1 (c1 TEXT NOT NULL, KEY c1 (c1(10))) ENGINE=MyISAM;
 INSERT INTO t1 VALUES
@@ -1430,22 +1430,22 @@
 DROP TABLE t1;
 CREATE TEMPORARY TABLE t1 (c1 INT, c2 INT, UNIQUE INDEX (c1), INDEX (c2)) ENGINE=MYISAM;
 SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 INSERT INTO t1 VALUES (1,1);
 SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
-ALTER TABLE t1 DISABLE KEYS;
-SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
-ALTER TABLE t1 ENABLE KEYS;
-SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
-ALTER TABLE t1 DISABLE KEYS;
-SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
-ALTER TABLE t1 ENABLE KEYS;
-SHOW TABLE STATUS LIKE 't1';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
+ALTER TABLE t1 DISABLE KEYS;
+SHOW TABLE STATUS LIKE 't1';
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
+ALTER TABLE t1 ENABLE KEYS;
+SHOW TABLE STATUS LIKE 't1';
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
+ALTER TABLE t1 DISABLE KEYS;
+SHOW TABLE STATUS LIKE 't1';
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
+ALTER TABLE t1 ENABLE KEYS;
+SHOW TABLE STATUS LIKE 't1';
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 # Enable keys with parallel repair
 SET GLOBAL myisam_repair_threads=2;
 ALTER TABLE t1 DISABLE KEYS;

=== modified file 'tests/r/select.result'
--- tests/r/select.result	2009-12-10 10:25:44 +0000
+++ tests/r/select.result	2010-01-03 23:56:16 +0000
@@ -2448,9 +2448,9 @@
 create table t11 like t1;
 insert into t1 values(1,""),(2,"");
 show table status like 't1%';
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
-t1	InnoDB	X	Compact	2	8192	X	X	X	X	X	X	X	X	utf8_general_ci	NULL		
-t11	InnoDB	X	Compact	0	0	X	X	X	X	X	X	X	X	utf8_general_ci	NULL		
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
+t1	InnoDB	X	Compact	2	8192	X	X	X	X	X	X	X	X	utf8_general_ci	NULL			NULL
+t11	InnoDB	X	Compact	0	0	X	X	X	X	X	X	X	X	utf8_general_ci	NULL			NULL
 select 123 as a from t1 where f1 is null;
 a
 drop table t1,t11;

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2009-12-01 18:40:22 +0000
+++ tests/r/show_check.result	2010-01-03 23:56:16 +0000
@@ -91,7 +91,8 @@
 def	information_schema	tables	TABLES	CHECKSUM	Checksum	5	20	0	Y	32768	0	63
 def	information_schema	tables	TABLES	CREATE_OPTIONS	Create_options	8	1020	0	Y	0	0	45
 def	information_schema	tables	TABLES	TABLE_COMMENT	Comment	8	8192	0	N	1	0	45
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+def	information_schema	tables	TABLES	PLUGIN_NAME	Plugin_name	8	256	0	Y	0	0	45
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 show databases;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
 def	information_schema	schemata	SCHEMATA	SCHEMA_NAME	Database	8	256	18	N	1	0	45
@@ -343,37 +344,37 @@
 insert into t2 values (1),(2);
 insert into t3 values (1,1),(2,2);
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 insert into t1 values (3),(4);
 insert into t2 values (3),(4);
 insert into t3 values (3,3),(4,4);
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 insert into t1 values (5);
 insert into t2 values (5);
 insert into t3 values (5,5);
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 delete from t1 where a=3;
 delete from t2 where b=3;
 delete from t3 where a=3;
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 truncate table t1;
 truncate table t2;
 truncate table t3;
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 insert into t1 values (5);
 insert into t2 values (5);
 insert into t3 values (5,5);
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 delete from t1 where a=5;
 delete from t2 where b=5;
 delete from t3 where a=5;
 show table status;
-Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment
+Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 drop table t1, t2, t3;
 CREATE TEMPORARY TABLE t1 (i int, KEY (i)) ENGINE=MEMORY;
 SHOW CREATE TABLE t1;

=== modified file 'tests/t/information_schema.test'
--- tests/t/information_schema.test	2009-11-29 06:12:52 +0000
+++ tests/t/information_schema.test	2010-01-05 01:41:25 +0000
@@ -127,7 +127,7 @@
 SELECT table_schema, count(*) FROM information_schema.TABLES
 WHERE table_name NOT LIKE 'ndb_%' AND 
 table_name NOT LIKE 'falcon%' AND
-table_name NOT LIKE 'MEMCACHED%'
+plugin_name IS NULL
 GROUP BY TABLE_SCHEMA;
 
 #
@@ -259,7 +259,7 @@
                   c2.column_name LIKE '%SCHEMA%'
         )
   AND t.table_name NOT LIKE 'falcon%'
-  AND t.table_name NOT LIKE 'MEMCACHED%';
+  AND t.plugin_name IS NULL;
 SELECT t.table_name, c1.column_name
   FROM information_schema.tables t
        INNER JOIN
@@ -275,7 +275,7 @@
                   c2.column_name LIKE '%SCHEMA%'
         )
   AND t.table_name NOT LIKE 'falcon%'
-  AND t.table_name NOT LIKE 'MEMCACHED%';
+  AND t.plugin_name IS NULL;
 
 #
 # Bug#21231: query with a simple non-correlated subquery over
@@ -313,7 +313,7 @@
 on t.table_schema = c1.table_schema AND t.table_name = c1.table_name
 where t.table_schema = 'information_schema' AND
       t.table_name not like 'falcon%' AND
-      t.table_name not like 'MEMCACHED%' AND
+      t.plugin_name IS NULL AND
         c1.ordinal_position =
         (select isnull(c2.column_type) -
          isnull(group_concat(c2.table_schema, '.', c2.table_name)) +
@@ -437,7 +437,9 @@
 #
 SELECT table_name, column_name
 FROM information_schema.columns
-WHERE table_name NOT LIKE 'MEMCACHED%'
+WHERE table_name IN
+(SELECT table_name FROM information_schema.tables 
+ WHERE plugin_name IS NULL)
 ORDER BY table_name;
 
 #
@@ -500,7 +502,7 @@
 #
 SELECT table_schema, table_name
 FROM information_schema.tables
-WHERE table_name NOT LIKE 'MEMCACHED%'
+WHERE plugin_name IS NULL
 ORDER BY table_name;
 
 # 

